@@ -4,12 +4,12 @@ The main prc.api client.
 
 """
 
-from .server import Server
-from .utility import Cache, CacheConfig, Requests
+from .utility import KeylessCache, Cache, CacheConfig, Requests
+from typing import Optional, TYPE_CHECKING, Literal
 from .utility.requests import CleanAsyncClient
-from .exceptions import PRCException
-from typing import Optional, TYPE_CHECKING, Dict, Literal
-from datetime import datetime
+from .exceptions import HTTPException
+from .webhooks import Webhooks
+from .server import Server
 import re
 
 if TYPE_CHECKING:
@@ -17,21 +17,34 @@ if TYPE_CHECKING:
 
 
 class GlobalCache:
-    """Global object caches and config. TTL in seconds, 0 to disable. (max_size, TTL)"""
+    """
+    Global object caches and config. TTL in seconds, 0 to disable. (max_size, TTL)
+    """
 
     def __init__(
         self,
         servers: CacheConfig = (3, 0),
         join_codes: CacheConfig = (3, 0),
         players: CacheConfig = (100, 0),
+        invalid_keys: CacheConfig = (25, 0),
     ):
         self.servers = Cache[str, Server](*servers)
         self.join_codes = Cache[str, str](*join_codes)
         self.players = Cache[int, "Player"](*players)
+        self.invalid_keys = KeylessCache[str](*invalid_keys)
 
 
 class PRC:
-    """The main PRC API client. Controls servers and global cache."""
+    """
+    The main PRC API client. Controls servers and global cache.
+
+    Parameters
+    ----------
+    global_key
+        The global authentication key (large scale apps), if any.
+    default_server_key
+        The default unique server key to use. This will allow you to use `get_server` without needing to pass a key.
+    """
 
     def __init__(
         self,
@@ -52,15 +65,28 @@ class PRC:
                 base_url=self._base_url + "/api-key",
                 headers={"Authorization": self._global_key},
                 session=self._session,
+                invalid_keys=self._global_cache.invalid_keys,
             )
             if self._global_key is not None
             else None
         )
 
+        self.webhooks = Webhooks(self)
+
     def get_server(
-        self, server_key: Optional[str] = None, ignore_global_key: bool = False
-    ):
-        """Get a server handler using a key. Defaults to `default_server_key` if no `server_key` is passed. Servers are cached and data is synced across the client. Setting `ignore_global_key` may reset the cached server if cached `ignore_global_key` is conflicting."""
+        self, server_key: Optional[str] = None, *, ignore_global_key: bool = False
+    ) -> Server:
+        """
+        Get a server handler using a key. Servers are cached and data is synced across the client.
+
+        Parameters
+        ----------
+        server_key
+            The unique server key used to authenticate requests. Defaults to `default_server_key`, if any.
+        ignore_global_key
+            Whether to ignore the client's global authentication key (if set). By default, it is not ignored. This may reset the cached server if the cached `ignore_global_key` is conflicting.
+        """
+
         if not server_key:
             server_key = self._default_server_key
 
@@ -93,30 +119,11 @@ class PRC:
                 ),
             )
 
-    async def get_stats(self):
-        """Get game statistics (ER:LC) using the PRC public statistics API."""
-        response = await self._session.get("https://policeroleplay.community/api/stats")
+    async def reset_key(self) -> None:
+        """
+        Reset the global key and generate a new one. The new key will be used automatically and will **NOT** be returned. This will reset all cache.
+        """
 
-        if response.is_success:
-
-            class GameStatistics:
-                def __init__(self, data: Dict) -> None:
-                    self.name = str(data.get("name", "Unknown"))
-                    self.playing = int(data.get("playing", 0))
-                    self.visits = int(data.get("visits", 0))
-                    self.favorites = int(data.get("favorites", 0))
-                    self.likes = int(data.get("likes", 0))
-                    fetched_at = data.get("fetchedAt")
-                    self.last_updated = (
-                        datetime.fromtimestamp(fetched_at)
-                        if fetched_at
-                        else datetime.now()
-                    )
-
-            return GameStatistics(response.json())
-
-    async def reset_key(self):
-        """Reset the global key and generate a new one. The new key will be used automatically and will **not** be returned. This will reset all cache."""
         if not self._key_requests or self._global_key is None:
             raise ValueError("No global key is set but is required")
 
@@ -129,14 +136,17 @@ class PRC:
             self._global_cache.players.clear()
 
             self._global_key = new_key
+        elif response.status_code == 403:
+            self._global_cache.invalid_keys.add(self._global_key)
+            raise HTTPException(
+                f"The global key provided is invalid and cannot be reset.",
+                status_code=response.status_code,
+            )
         else:
-            if response.status_code == 403:
-                self._key_requests._invalid_keys.add(self._global_key)
-                raise PRCException(
-                    f"The global key provided is invalid and cannot be reset."
-                )
-            else:
-                raise PRCException("An unknown error has occured.")
+            raise HTTPException(
+                f"An unknown error has occured while resetting the global key.",
+                status_code=response.status_code,
+            )
 
     def _get_player(self, id: Optional[int] = None, name: Optional[str] = None):
         for _, player in self._global_cache.players.items():
