@@ -8,7 +8,9 @@ if TYPE_CHECKING:
 
 
 class AccountRequirement(DisplayNameEnum):
-    """Enum that represents a server account verification requirements that players must fulfill in order to join."""
+    """
+    Enum that represents a server account verification requirements that players must fulfill in order to join.
+    """
 
     DISABLED = (0, "Disabled")
     EMAIL = (1, "Email")
@@ -16,7 +18,16 @@ class AccountRequirement(DisplayNameEnum):
 
 
 class ServerStatus:
-    """Represents a server status with information about the server."""
+    """
+    Represents a server status with information about the server.
+
+    Parameters
+    ----------
+    server
+        The server handler.
+    data
+        The response data.
+    """
 
     def __init__(self, server: "Server", data: "v1_ServerStatusResponse"):
         self.name = str(data.get("Name"))
@@ -41,16 +52,31 @@ class ServerStatus:
         server.team_balance = self.team_balance
 
     @property
-    def join_link(self):
-        """Web URL that allows users to join the game and queue automatically for the server. Hosted by PRC. ⚠️ *(May not function properly on mobile devices -- May not function at random times)*"""
+    def join_link(self) -> str:
+        """
+        Web URL that allows users to join the game and queue automatically for the server.
+        Hosted by PRC. Server status must be fetched separately. ⚠️ *(May not function properly on mobile devices -- May not function at random times)*
+        """
+
         return "https://policeroleplay.community/join/" + self.join_code
 
     def is_online(self) -> bool:
-        """Whether the server is online (i.e. has online players)."""
+        """
+        Whether the server is online (i.e. has any online players). Server status or players must be fetched separately.
+        """
+
         return self.player_count > 0
 
     def is_full(self, include_reserved: bool = False) -> bool:
-        """Whether the server player count has reached the max player limit. Excludes owner-reserved spot by default (`max_players - 1`), set `include_reserved=True` to include."""
+        """
+        Whether the server player count has reached the max player limit. Server status must be fetched separately.
+
+        Parameters
+        ----------
+        include_reserved
+            Whether to include the owner-reserved spot. By default, it is excluded (`max_players - 1`).
+        """
+
         return self.player_count >= self.max_players - (0 if include_reserved else 1)
 
     def __repr__(self) -> str:
