@@ -1,7 +1,7 @@
+from ..exceptions import HTTPException, PRCException, RequestTimeout
 from typing import Dict, Optional, TypeVar, Generic
 from time import time
 from .cache import Cache, KeylessCache
-from ..exceptions import PRCException
 import asyncio
 import httpx
 
@@ -60,7 +60,10 @@ class RateLimiter:
             resets_in = bucket.reset_at - time()
             if resets_in > 0:
                 if resets_in > max_retry_after:
-                    raise PRCException("An IP ban has likely occured.")
+                    raise HTTPException(
+                        f"Rate limit exceeded max threshold ({max_retry_after}s). An IP ban or limit has likely occured.",
+                        status_code=429,
+                    )
                 await asyncio.sleep(resets_in)
             else:
                 self.buckets.delete(bucket.name)
@@ -74,15 +77,20 @@ class RateLimiter:
                 return False
             else:
                 await asyncio.sleep(retry_after)
-        return True
+                return True
+
+        return False
 
 
 class Requests(Generic[R]):
-    """Handles outgoing API requests while respecting rate limits."""
+    """
+    Handles outgoing API requests while respecting rate limits.
+    """
 
     def __init__(
         self,
         base_url: str,
+        invalid_keys: KeylessCache[str],
         headers: Optional[Dict[str, str]] = None,
         session: Optional[CleanAsyncClient] = None,
         max_retries: int = 3,
@@ -98,7 +106,7 @@ class Requests(Generic[R]):
         self._max_retry_after = max_retry_after
         self._timeout = timeout
 
-        self._invalid_keys = KeylessCache[str](max_size=20)
+        self._invalid_keys = invalid_keys
 
     def _can_retry(self, status_code: int = 500, retry: int = 0):
         return (status_code == 429 or status_code >= 500) and retry < self._max_retries
@@ -107,7 +115,7 @@ class Requests(Generic[R]):
         for header, value in self._default_headers.items():
             if value in self._invalid_keys:
                 raise PRCException(
-                    f"Cannot reuse an invalid API key from default header: {header}"
+                    f"Cannot reuse an invalid API key from default header: '{header}'"
                 )
 
     async def _make_request(
@@ -119,6 +127,11 @@ class Requests(Generic[R]):
         url = f"{self._base_url}{route}"
         headers = {**self._default_headers, **kwargs.pop("headers", {})}
 
+        async def resend():
+            return await self._make_request(
+                method, route, retry + 1, **kwargs, headers=headers
+            )
+
         try:
             response = await self._session.request(
                 method,
@@ -130,11 +143,9 @@ class Requests(Generic[R]):
         except httpx.ReadTimeout:
             if self._can_retry(retry=retry):
                 await asyncio.sleep(retry * 1.5)
-                return await self._make_request(method, route, retry + 1, **kwargs)
+                return await resend()
             else:
-                raise PRCException(
-                    f"PRC API took too long to respond. ({retry}/{self._max_retries} retries) ({self._timeout}s timeout)"
-                )
+                raise RequestTimeout(retry, self._max_retries, self._timeout)
 
         self._rate_limiter.save_bucket(route, response.headers)
 
@@ -142,7 +153,10 @@ class Requests(Generic[R]):
             if await self._rate_limiter.wait_to_retry(
                 response.headers, self._max_retry_after
             ):
-                return await self._make_request(method, route, retry + 1, **kwargs)
+                return await resend()
+            else:
+                await asyncio.sleep(retry * 1.5)
+                return await resend()
 
         return response
 
